summaryrefslogtreecommitdiff
path: root/connectivity/source/inc/java
diff options
context:
space:
mode:
authorNorbert Thiebaud <nthiebaud@gmail.com>2011-02-11 16:27:37 -0600
committerNorbert Thiebaud <nthiebaud@gmail.com>2011-02-11 16:27:37 -0600
commit8cc8ec8b94a36300a3f037885462e06a7749b36f (patch)
treee6c68e506d6215be069be9e7d95bcf957f3430d3 /connectivity/source/inc/java
parentcf109aacb26616e1cff76a7c0983fe5dfcd81b2a (diff)
merge non-conflicting changes to connectivity
Diffstat (limited to 'connectivity/source/inc/java')
-rw-r--r--connectivity/source/inc/java/ContextClassLoader.hxx3
-rw-r--r--connectivity/source/inc/java/GlobalRef.hxx3
-rw-r--r--connectivity/source/inc/java/LocalRef.hxx3
-rw-r--r--connectivity/source/inc/java/io/InputStream.hxx2
-rw-r--r--connectivity/source/inc/java/io/Reader.hxx2
-rw-r--r--connectivity/source/inc/java/lang/Boolean.hxx2
-rw-r--r--connectivity/source/inc/java/lang/Class.hxx2
-rw-r--r--connectivity/source/inc/java/lang/Exception.hxx2
-rw-r--r--connectivity/source/inc/java/lang/Object.hxx2
-rw-r--r--connectivity/source/inc/java/lang/String.hxx2
-rw-r--r--connectivity/source/inc/java/lang/Throwable.hxx2
-rw-r--r--connectivity/source/inc/java/math/BigDecimal.hxx2
-rw-r--r--connectivity/source/inc/java/sql/Array.hxx2
-rw-r--r--connectivity/source/inc/java/sql/Blob.hxx2
-rw-r--r--connectivity/source/inc/java/sql/CallableStatement.hxx2
-rw-r--r--connectivity/source/inc/java/sql/Clob.hxx2
-rw-r--r--connectivity/source/inc/java/sql/Connection.hxx2
-rw-r--r--connectivity/source/inc/java/sql/ConnectionLog.hxx3
-rw-r--r--connectivity/source/inc/java/sql/DatabaseMetaData.hxx2
-rw-r--r--connectivity/source/inc/java/sql/Driver.hxx2
-rw-r--r--connectivity/source/inc/java/sql/DriverPropertyInfo.hxx2
-rw-r--r--connectivity/source/inc/java/sql/JStatement.hxx2
-rw-r--r--connectivity/source/inc/java/sql/PreparedStatement.hxx2
-rw-r--r--connectivity/source/inc/java/sql/Ref.hxx2
-rw-r--r--connectivity/source/inc/java/sql/ResultSet.hxx2
-rw-r--r--connectivity/source/inc/java/sql/ResultSetMetaData.hxx2
-rw-r--r--connectivity/source/inc/java/sql/SQLException.hxx2
-rw-r--r--connectivity/source/inc/java/sql/SQLWarning.hxx5
-rw-r--r--connectivity/source/inc/java/sql/Timestamp.hxx8
-rw-r--r--connectivity/source/inc/java/tools.hxx8
-rw-r--r--connectivity/source/inc/java/util/Date.hxx2
-rw-r--r--connectivity/source/inc/java/util/Property.hxx3
32 files changed, 74 insertions, 10 deletions
diff --git a/connectivity/source/inc/java/ContextClassLoader.hxx b/connectivity/source/inc/java/ContextClassLoader.hxx
index 4770053d25..f1f49f0af8 100644
--- a/connectivity/source/inc/java/ContextClassLoader.hxx
+++ b/connectivity/source/inc/java/ContextClassLoader.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -101,3 +102,5 @@ namespace connectivity { namespace jdbc
//........................................................................
#endif // CONNECTIVITY_CONTEXTCLASSLOADER_HXX
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/GlobalRef.hxx b/connectivity/source/inc/java/GlobalRef.hxx
index e8ed863b3b..b6db5de516 100644
--- a/connectivity/source/inc/java/GlobalRef.hxx
+++ b/connectivity/source/inc/java/GlobalRef.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -120,3 +121,5 @@ namespace connectivity { namespace jdbc
//........................................................................
#endif // CONNECTIVITY_GLOBALREF_HXX
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/LocalRef.hxx b/connectivity/source/inc/java/LocalRef.hxx
index 34eae94759..6f499ced88 100644
--- a/connectivity/source/inc/java/LocalRef.hxx
+++ b/connectivity/source/inc/java/LocalRef.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -104,3 +105,5 @@ namespace connectivity { namespace jdbc
//........................................................................
#endif // CONNECTIVITY_LOCALREF_HXX
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/io/InputStream.hxx b/connectivity/source/inc/java/io/InputStream.hxx
index 918ca7678b..5fdb5a5abb 100644
--- a/connectivity/source/inc/java/io/InputStream.hxx
+++ b/connectivity/source/inc/java/io/InputStream.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -58,3 +59,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_IO_INPUTSTREAM_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/io/Reader.hxx b/connectivity/source/inc/java/io/Reader.hxx
index 584de41c45..74235ff5d3 100644
--- a/connectivity/source/inc/java/io/Reader.hxx
+++ b/connectivity/source/inc/java/io/Reader.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -59,3 +60,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_IO_READER_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/lang/Boolean.hxx b/connectivity/source/inc/java/lang/Boolean.hxx
index fe237fb2fd..4c036bdf18 100644
--- a/connectivity/source/inc/java/lang/Boolean.hxx
+++ b/connectivity/source/inc/java/lang/Boolean.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,3 +52,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_LANG_BOOLEAN_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/lang/Class.hxx b/connectivity/source/inc/java/lang/Class.hxx
index cbf46ad3a7..b0ce998314 100644
--- a/connectivity/source/inc/java/lang/Class.hxx
+++ b/connectivity/source/inc/java/lang/Class.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -53,3 +54,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_LANG_CLASS_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/lang/Exception.hxx b/connectivity/source/inc/java/lang/Exception.hxx
index 9619b28216..2eb76b5aef 100644
--- a/connectivity/source/inc/java/lang/Exception.hxx
+++ b/connectivity/source/inc/java/lang/Exception.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -49,3 +50,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_LANG_EXCEPTION_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/lang/Object.hxx b/connectivity/source/inc/java/lang/Object.hxx
index f60099e43c..b017163de7 100644
--- a/connectivity/source/inc/java/lang/Object.hxx
+++ b/connectivity/source/inc/java/lang/Object.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -173,3 +174,4 @@ namespace connectivity
#endif //_CONNECTIVITY_JAVA_LANG_OBJJECT_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/lang/String.hxx b/connectivity/source/inc/java/lang/String.hxx
index 3bc3631bd7..f39664e77b 100644
--- a/connectivity/source/inc/java/lang/String.hxx
+++ b/connectivity/source/inc/java/lang/String.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,3 +52,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_LANG_STRING_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/lang/Throwable.hxx b/connectivity/source/inc/java/lang/Throwable.hxx
index aa96d89fb4..9915adbea7 100644
--- a/connectivity/source/inc/java/lang/Throwable.hxx
+++ b/connectivity/source/inc/java/lang/Throwable.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -52,3 +53,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_LANG_THROWABLE_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/math/BigDecimal.hxx b/connectivity/source/inc/java/math/BigDecimal.hxx
index a2f7c7be5b..39f02eca41 100644
--- a/connectivity/source/inc/java/math/BigDecimal.hxx
+++ b/connectivity/source/inc/java/math/BigDecimal.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,3 +52,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_MATH_BIGDECIMAL_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Array.hxx b/connectivity/source/inc/java/sql/Array.hxx
index ec044db382..b3e6d4ffa0 100644
--- a/connectivity/source/inc/java/sql/Array.hxx
+++ b/connectivity/source/inc/java/sql/Array.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -61,3 +62,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_ARRAY_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Blob.hxx b/connectivity/source/inc/java/sql/Blob.hxx
index c0a257028a..754b38b09e 100644
--- a/connectivity/source/inc/java/sql/Blob.hxx
+++ b/connectivity/source/inc/java/sql/Blob.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -61,3 +62,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_BLOB_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/CallableStatement.hxx b/connectivity/source/inc/java/sql/CallableStatement.hxx
index dab15e6c01..00fd44c6fb 100644
--- a/connectivity/source/inc/java/sql/CallableStatement.hxx
+++ b/connectivity/source/inc/java/sql/CallableStatement.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -89,3 +90,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_CALLABLESTATEMENT_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Clob.hxx b/connectivity/source/inc/java/sql/Clob.hxx
index 86323b0287..01265210c3 100644
--- a/connectivity/source/inc/java/sql/Clob.hxx
+++ b/connectivity/source/inc/java/sql/Clob.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -61,3 +62,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_CLOB_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Connection.hxx b/connectivity/source/inc/java/sql/Connection.hxx
index b388c5838e..211e950a88 100644
--- a/connectivity/source/inc/java/sql/Connection.hxx
+++ b/connectivity/source/inc/java/sql/Connection.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -149,3 +150,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_CONNECTION_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/ConnectionLog.hxx b/connectivity/source/inc/java/sql/ConnectionLog.hxx
index 31de60bf5f..74bddcd5b9 100644
--- a/connectivity/source/inc/java/sql/ConnectionLog.hxx
+++ b/connectivity/source/inc/java/sql/ConnectionLog.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -140,3 +141,5 @@ namespace connectivity { namespace java { namespace sql {
//........................................................................
#endif // CONNECTIVITY_CONNECTIONLOG_HXX
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/DatabaseMetaData.hxx b/connectivity/source/inc/java/sql/DatabaseMetaData.hxx
index c1a918ba15..e0bd590cc1 100644
--- a/connectivity/source/inc/java/sql/DatabaseMetaData.hxx
+++ b/connectivity/source/inc/java/sql/DatabaseMetaData.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -222,3 +223,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_DATABASEMETADATA_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Driver.hxx b/connectivity/source/inc/java/sql/Driver.hxx
index 5921c4e9dd..508429c301 100644
--- a/connectivity/source/inc/java/sql/Driver.hxx
+++ b/connectivity/source/inc/java/sql/Driver.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -74,3 +75,4 @@ namespace connectivity
}
#endif //_CONNECTIVITY_JAVA_SQL_DRIVER_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/DriverPropertyInfo.hxx b/connectivity/source/inc/java/sql/DriverPropertyInfo.hxx
index 6a76135459..0e6955aa71 100644
--- a/connectivity/source/inc/java/sql/DriverPropertyInfo.hxx
+++ b/connectivity/source/inc/java/sql/DriverPropertyInfo.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -59,3 +60,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_SQL_DRIVERPOPERTYINFO_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/JStatement.hxx b/connectivity/source/inc/java/sql/JStatement.hxx
index e3b1bb354b..39f232c8d5 100644
--- a/connectivity/source/inc/java/sql/JStatement.hxx
+++ b/connectivity/source/inc/java/sql/JStatement.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -217,3 +218,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_STATEMENT_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/PreparedStatement.hxx b/connectivity/source/inc/java/sql/PreparedStatement.hxx
index 6cae07fadb..0e3932cfc2 100644
--- a/connectivity/source/inc/java/sql/PreparedStatement.hxx
+++ b/connectivity/source/inc/java/sql/PreparedStatement.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -111,3 +112,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_PREPAREDSTATEMENT_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Ref.hxx b/connectivity/source/inc/java/sql/Ref.hxx
index b8b9a53398..d4479be3bb 100644
--- a/connectivity/source/inc/java/sql/Ref.hxx
+++ b/connectivity/source/inc/java/sql/Ref.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -56,3 +57,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_REF_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/ResultSet.hxx b/connectivity/source/inc/java/sql/ResultSet.hxx
index be6774db09..5764fec3cf 100644
--- a/connectivity/source/inc/java/sql/ResultSet.hxx
+++ b/connectivity/source/inc/java/sql/ResultSet.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -206,3 +207,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_RESULTSET_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/ResultSetMetaData.hxx b/connectivity/source/inc/java/sql/ResultSetMetaData.hxx
index e923ae833a..c0f43cbb8d 100644
--- a/connectivity/source/inc/java/sql/ResultSetMetaData.hxx
+++ b/connectivity/source/inc/java/sql/ResultSetMetaData.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -80,3 +81,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_RESULTSETMETADATA_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/SQLException.hxx b/connectivity/source/inc/java/sql/SQLException.hxx
index 19c8a12b6b..6ff404cbef 100644
--- a/connectivity/source/inc/java/sql/SQLException.hxx
+++ b/connectivity/source/inc/java/sql/SQLException.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -66,3 +67,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_SQLEXCEPTION_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/SQLWarning.hxx b/connectivity/source/inc/java/sql/SQLWarning.hxx
index a5591b525f..8026d0ac5f 100644
--- a/connectivity/source/inc/java/sql/SQLWarning.hxx
+++ b/connectivity/source/inc/java/sql/SQLWarning.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,9 +30,6 @@
#define _CONNECTIVITY_JAVA_SQL_SQLWARNING_HXX_
#include "java/sql/SQLException.hxx"
-//#ifndef _COM_SUN_STAR_SDBC_SQLWARNING_HPP_
-//#include <com/sun/star/sdbc/SQLWarning.hpp>
-//#endif
namespace connectivity
{
@@ -62,3 +60,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_SQLWARNING_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/sql/Timestamp.hxx b/connectivity/source/inc/java/sql/Timestamp.hxx
index 1944dc4aa8..9fd3ea4218 100644
--- a/connectivity/source/inc/java/sql/Timestamp.hxx
+++ b/connectivity/source/inc/java/sql/Timestamp.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -41,7 +42,7 @@ namespace connectivity
class java_sql_Date : public java_util_Date
{
protected:
- // statische Daten fuer die Klasse
+ // static data for the class
static jclass theClass;
public:
virtual jclass getMyClass() const;
@@ -62,7 +63,7 @@ namespace connectivity
class java_sql_Time : public java_util_Date
{
protected:
- // statische Daten fuer die Klasse
+ // static data for the class
static jclass theClass;
public:
virtual jclass getMyClass() const;
@@ -80,7 +81,7 @@ namespace connectivity
class java_sql_Timestamp : public java_util_Date
{
protected:
- // statische Daten fuer die Klasse
+ // static data for the class
static jclass theClass;
public:
virtual jclass getMyClass() const;
@@ -97,3 +98,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_SQL_TIMESTAMP_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/util/Date.hxx b/connectivity/source/inc/java/util/Date.hxx
index 524b13359e..7c8c7a9811 100644
--- a/connectivity/source/inc/java/util/Date.hxx
+++ b/connectivity/source/inc/java/util/Date.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -52,3 +53,4 @@ namespace connectivity
}
#endif // _CONNECTIVITY_JAVA_UTIL_DATE_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/util/Property.hxx b/connectivity/source/inc/java/util/Property.hxx
index bada9d0d23..b3de8690c5 100644
--- a/connectivity/source/inc/java/util/Property.hxx
+++ b/connectivity/source/inc/java/util/Property.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -47,3 +48,5 @@ namespace connectivity
}
#endif // CONNECTIVITY_java_util_Properties
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/inc/java/tools.hxx b/connectivity/source/inc/java/tools.hxx
index b917c0dd0c..21764b457d 100644
--- a/connectivity/source/inc/java/tools.hxx
+++ b/connectivity/source/inc/java/tools.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
#include <com/sun/star/beans/PropertyValue.hpp>
#include <com/sun/star/uno/Sequence.h>
-#ifndef JNI_H
#include <jni.h>
-#endif
#include "java/sql/SQLException.hxx"
#include <comphelper/uno3.hxx>
@@ -74,13 +73,13 @@ namespace connectivity
::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > Map2XNameAccess(JNIEnv *pEnv,jobject _pMap);
jobject convertTypeMapToJavaMap(JNIEnv *pEnv,const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & _rMap);
/** return if a exception occured
@param pEnv
The native java env
@param _bClear
<TRUE/> if the execption should be cleared
@return
- <TRUE/> if an exception is occured
+ <TRUE/> if an exception is occurred
*/
sal_Bool isExceptionOccured(JNIEnv *pEnv,sal_Bool _bClear);
@@ -90,3 +89,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_TOOLS_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -74,13 +73,13 @@ namespace connectivity
::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > Map2XNameAccess(JNIEnv *pEnv,jobject _pMap);
jobject convertTypeMapToJavaMap(JNIEnv *pEnv,const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & _rMap);
- /** return if a exception occured
+ /** return if a exception occurred
The native java env